@@ -39,6 +39,8 @@ from lightbulb import converters
 from lightbulb import cooldowns
 
 if typing.TYPE_CHECKING:
+    import hikari
+
     from lightbulb import plugins
 
 _LOGGER = logging.getLogger("lightbulb")
@@ -61,6 +63,12 @@ def _bind_prototype(instance: typing.Any, command_template: _CommandT):
             self._delegates_to = command_template
             self.__dict__.update(command_template.__dict__)
 
+        def __hash__(self) -> int:
+            return hash(self.name)
+
+        def __eq__(self, other) -> bool:
+            return isinstance(other, (type(self), Command)) and other.name == self.name
+
         async def invoke(self, context: context.Context, *args: str, **kwargs: str) -> typing.Any:
             if self.cooldown_manager is not None:
                 self.cooldown_manager.add_cooldown(context)
@@ -193,12 +201,14 @@ class Command:
         name: str,
         allow_extra_arguments: bool,
         aliases: typing.Iterable[str],
+        hidden: bool,
         parent: typing.Optional[typing.Any] = None,
     ) -> None:
         self._callback = callback
         self._name = name
         self._allow_extra_arguments = allow_extra_arguments
         self._aliases = aliases
+        self.hidden = hidden
         self._checks = []
         self._error_listener = None
         self.method_name: typing.Optional[str] = None
@@ -206,6 +216,16 @@ class Command:
         """The parent group for the command. If ``None`` then the command is not a subcommand."""
         self.plugin: typing.Optional[plugins.Plugin] = None
         """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
+        self.user_required_permissions: typing.Set[hikari.Permissions] = set()
+        """
+        The permissions required by a user to run the command. 
+        These are extracted from the permission check decorator(s) on the command.
+        """
+        self.bot_required_permissions: typing.Set[hikari.Permissions] = set()
+        """
+        The permissions the bot requires for a user to be able to run the command. 
+        These are extracted from the permission check decorator(s) on the command.
+        """
 
         self.cooldown_manager: typing.Optional[cooldowns.CooldownManager] = None
         """The cooldown manager being used for the command. If ``None`` then the command does not have a cooldown."""
@@ -227,6 +247,12 @@ class Command:
     def __repr__(self) -> str:
         return f"<lightbulb.{self.__class__.__name__} {self.name} at {hex(id(self))}>"
 
+    def __hash__(self) -> int:
+        return hash(self.name)
+
+    def __eq__(self, other) -> bool:
+        return isinstance(other, type(self)) and other.name == self.name
+
     @functools.cached_property
     def arg_details(self) -> SignatureInspector:
         """
@@ -248,7 +274,7 @@ class Command:
         return self._name
 
     @property
-    def aliases(self) -> str:
+    def aliases(self) -> typing.Iterable[str]:
         """
         The command's aliases.
 
@@ -466,7 +492,12 @@ class Group(Command):
             name = kwargs.get("name", func.__name__)
             cls = kwargs.get("cls", Command)
             self._subcommands[name] = cls(
-                func, name, kwargs.get("allow_extra_arguments", True), kwargs.get("aliases", []), parent=self,
+                func,
+                name,
+                kwargs.get("allow_extra_arguments", True),
+                kwargs.get("aliases", []),
+                kwargs.get("hidden", False),
+                parent=self,
             )
             if self.inherit_checks:
                 self._subcommands[name]._checks.extend(self._checks)
@@ -497,6 +528,7 @@ class Group(Command):
                 name,
                 kwargs.get("allow_extra_arguments", True),
                 kwargs.get("aliases", []),
+                kwargs.get("hidden", False),
                 insensitive_commands=kwargs.get("insensitive_commands", False),
                 inherit_checks=kwargs.get("inherit_checks", True),
                 parent=self,
@@ -520,6 +552,7 @@ def command(**kwargs):
         allow_extra_arguments (Optional[ :obj:`bool` ]): Whether or not the command should error when run with
             more arguments than it takes. Defaults to True - will not raise an error.
         aliases (Iterable[ :obj:`str` ]): Iterable of aliases which will also invoke the command.
+        hidden (:obj:`bool`): Whether or not the command should be hidden from the help command. Defaults to ``False``.
         cls (:obj:`~.commands.Command`): The class to use to instantiate the command object from. Defaults
             to :obj:`~.commands.Command`.
     """
@@ -527,7 +560,13 @@ def command(**kwargs):
     def decorate(func):
         name = kwargs.get("name", func.__name__)
         cls = kwargs.get("cls", Command)
-        return cls(func, name, kwargs.get("allow_extra_arguments", True), kwargs.get("aliases", []))
+        return cls(
+            func,
+            name,
+            kwargs.get("allow_extra_arguments", True),
+            kwargs.get("aliases", []),
+            kwargs.get("hidden", False),
+        )
 
     return decorate
 
@@ -541,6 +580,7 @@ def group(**kwargs):
         allow_extra_arguments (Optional[ :obj:`bool` ]): Whether or not the command should error when run with
             more arguments than it takes. Defaults to True - will not raise an error.
         aliases (Optional[ Iterable[ :obj:`str` ] ]): Iterable of aliases which will also invoke the command.
+        hidden (:obj:`bool`): Whether or not the command should be hidden from the help command. Defaults to ``False``.
         insensitive_commands (:obj:`bool`): Whether or not subcommands should be case-insensitive. Defaults to
             False.
         cls (:obj:`~.commands.Command`): The class to use to instantiate the group object from. Defaults
@@ -556,6 +596,7 @@ def group(**kwargs):
             name,
             kwargs.get("allow_extra_arguments", True),
             kwargs.get("aliases", []),
+            kwargs.get("hidden", False),
             insensitive_commands=kwargs.get("insensitive_commands", False),
             inherit_checks=kwargs.get("inherit_checks", True),
         )
